<?php
/**
 * Dumbo Theme Customizer
 *
 * @package Dumbo
 */

/** Sanitize Functions. **/
	require get_template_directory() . '/inc/customizer/default.php';

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
if (!function_exists('dumbo_customize_register')) :

function dumbo_customize_register( $wp_customize ) {

	require get_template_directory() . '/inc/customizer/custom-classes.php';
	require get_template_directory() . '/inc/customizer/sanitize.php';
	require get_template_directory() . '/inc/customizer/header.php';
	require get_template_directory() . '/inc/customizer/banner.php';
	require get_template_directory() . '/inc/customizer/banner-slider.php';
	require get_template_directory() . '/inc/customizer/twp-category-section.php';
	require get_template_directory() . '/inc/customizer/about.php';
	require get_template_directory() . '/inc/customizer/cta.php';
	require get_template_directory() . '/inc/customizer/contact.php';
	require get_template_directory() . '/inc/customizer/pagination.php';
	require get_template_directory() . '/inc/customizer/post.php';
	require get_template_directory() . '/inc/customizer/single.php';
	require get_template_directory() . '/inc/customizer/footer.php';
	require get_template_directory() . '/inc/customizer/color-scheme.php';
	require get_template_directory() . '/inc/customizer/newsletter.php';
	require get_template_directory() . '/inc/customizer/related-post.php';

	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';
	$wp_customize->get_section( 'static_front_page' )->panel = 'homepage_option_panel';
	$wp_customize->get_section( 'static_front_page' )->title = esc_html__('Homepage Page/Post Option','dumbo');
	$wp_customize->get_section( 'colors' )->panel = 'theme_colors_panel';
	$wp_customize->get_section( 'colors' )->title = esc_html__('Color Options','dumbo');
	$wp_customize->get_section( 'title_tagline' )->panel = 'theme_general_settings';
	$wp_customize->get_section( 'background_image' )->panel = 'theme_general_settings';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'blogname', array(
			'selector'        => '.site-title a',
			'render_callback' => 'dumbo_customize_partial_blogname',
		) );
		$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
			'selector'        => '.site-description',
			'render_callback' => 'dumbo_customize_partial_blogdescription',
		) );
	}

	$wp_customize->add_setting('logo_width_range',
	    array(
	        'default'           => $dumbo_default['logo_width_range'],
	        'capability'        => 'edit_theme_options',
	        'sanitize_callback' => 'dumbo_sanitize_number_range',
	    )
	);
	$wp_customize->add_control('logo_width_range',
	    array(
	        'label'       => esc_html__('Logo With', 'dumbo'),
	        'description'       => esc_html__( 'Define logo size min-100 to max-700 (step-20)', 'dumbo' ),
	        'section'     => 'title_tagline',
	        'type'        => 'range',
	        'input_attrs' => array(
				           'min'   => 100,
				           'max'   => 700,
				           'step'   => 25,
			        	),
	    )
	);
	// Homepage Options Panel.
	$wp_customize->add_panel( 'homepage_option_panel',
		array(
			'title'      => esc_html__( 'HomePage Options', 'dumbo' ),
			'priority'   => 150,
			'capability' => 'edit_theme_options',
		)
	);
	
	// Theme Options Panel.
	$wp_customize->add_panel( 'theme_option_panel',
		array(
			'title'      => esc_html__( 'Theme Options', 'dumbo' ),
			'priority'   => 150,
			'capability' => 'edit_theme_options',
		)
	);


	$wp_customize->add_panel( 'theme_general_settings',
		array(
			'title'      => esc_html__( 'General Settings', 'dumbo' ),
			'priority'   => 10,
			'capability' => 'edit_theme_options',
		)
	);

	$wp_customize->add_panel( 'theme_colors_panel',
		array(
			'title'      => esc_html__( 'Color Settings', 'dumbo' ),
			'priority'   => 15,
			'capability' => 'edit_theme_options',
		)
	);

	// Theme Options Panel.
	$wp_customize->add_panel( 'theme_footer_option_panel',
		array(
			'title'      => esc_html__( 'Footer Setting', 'dumbo' ),
			'priority'   => 150,
			'capability' => 'edit_theme_options',
		)
	);	

	$dumbo_defaults = dumbo_get_default_theme_options();
	$home_section_arrange_vals_3 = get_theme_mod( 'home_section_arrange_vals_3', $dumbo_defaults['home_section_arrange_vals_3'] );
	$home_section_arrange_vals_3 = explode(",",$home_section_arrange_vals_3 );


	$j = 1;
	foreach( $home_section_arrange_vals_3 as $home_section_arrange ){
	    if ($j <= 5) {
	        $wp_customize->get_section( $home_section_arrange )->priority = $j;
	    }   
	    
	    $j ++;
	}

	// Register custom section types.
	$wp_customize->register_section_type( 'Dumbo_Customize_Section_Upsell' );

	// Register sections.
	$wp_customize->add_section(
		new Dumbo_Customize_Section_Upsell(
			$wp_customize,
			'theme_upsell',
			array(
				'title'    => esc_html__( 'Dumbo Pro', 'dumbo' ),
				'pro_text' => esc_html__( 'Purchase', 'dumbo' ),
				'pro_url'  => esc_url('https://www.themeinwp.com/theme/dumbo-pro/'),
				'priority'  => 1,
			)
		)
	);

}

endif;
add_action( 'customize_register', 'dumbo_customize_register' );

add_action( 'wp_ajax_dumbo_arrange_home_section', 'dumbo_arrange_home_section' );
add_action('wp_ajax_nopriv_dumbo_arrange_home_section', 'dumbo_arrange_home_section');

function dumbo_arrange_home_section() {

	if ( isset( $_POST['sections'] ) ) {

		set_theme_mod( 'home_section_arrange_vals_3', wp_unslash( $_POST['sections'] ) );
		
	}
	wp_die(); // this is required to terminate immediately and return a proper response
}

/**
 * Customizer Enqueue scripts and styles.
 */

if (!function_exists('dumbo_customizer_scripts')) :

    function dumbo_customizer_scripts(){   
    	
    	wp_enqueue_script('jquery-ui-button');
    	wp_enqueue_style('dumbo-repeater', get_template_directory_uri() . '/assets/lib/custom/css/repeater.css');
    	wp_enqueue_style('dumbo-customizer', get_template_directory_uri() . '/assets/lib/custom/css/customizer.css');
        wp_enqueue_script('dumbo-customizer', get_template_directory_uri() . '/assets/lib/custom/js/customizer.js', array('jquery','customize-controls'), '', 1);
        wp_enqueue_script('dumbo-repeater', get_template_directory_uri() . '/assets/lib/custom/js/repeater.js', array('jquery','customize-controls'), '', 1);
    	wp_enqueue_script('dumbo-re-customizer', get_template_directory_uri() . '/assets/lib/custom/js/re-customizer.js', array('jquery','customize-controls'), '', 1);

        $dumbo_post_category_list = dumbo_post_category_list();

	    $cat_option = '';

	    if( $dumbo_post_category_list ){
		    foreach( $dumbo_post_category_list as $key => $cats ){
		    	$cat_option .= "<option value='". esc_attr( $key )."'>". esc_html( $cats )."</option>";
		    }
		}

	    wp_localize_script( 
	        'dumbo-repeater', 
	        'dumbo_repeater',
	        array(
	           	'categories'   => $cat_option,
	            'upload_image'   =>  esc_html__('Choose Image','dumbo'),
	            'use_image'   =>  esc_html__('Select','dumbo'),
	         )
	    );

        $ajax_nonce = wp_create_nonce('dumbo_ajax_nonce');
        wp_localize_script( 
		    'dumbo-customizer', 
		    'dumbo_customizer',
		    array(
		        'ajax_url'   => esc_url( admin_url( 'admin-ajax.php' ) ),
		        'ajax_nonce' => $ajax_nonce,
		     )
		);

	        $home_section_arrange_vals_3 = get_theme_mod( 'home_section_arrange_vals_3' );
	        $home_section_arrange_vals_3 = explode(",",$home_section_arrange_vals_3 );
	        $key_sidebar = '';
	        $home_url = esc_url( home_url('/') );
	        wp_localize_script( 
			    'dumbo-re-customizer', 
			    'dumbo_re_customizer',
			    array(
			        'ajax_url'   => esc_url( admin_url( 'admin-ajax.php' ) ),
			        'ajax_nonce' => $ajax_nonce,
			        'key_sidebar' => $key_sidebar,
			        'home_url' => $home_url,
			     )
			);
    }

endif;

add_action('customize_controls_enqueue_scripts', 'dumbo_customizer_scripts');
add_action('customize_controls_init', 'dumbo_customizer_scripts');

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */

if (!function_exists('dumbo_customize_partial_blogname')) :

	function dumbo_customize_partial_blogname() {
		bloginfo( 'name' );
	}
endif;

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */

if (!function_exists('dumbo_customize_partial_blogdescription')) :

	function dumbo_customize_partial_blogdescription() {
		bloginfo( 'description' );
	}

endif;


add_action('wp_ajax_dumbo_customizer_font_weight', 'dumbo_customizer_font_weight_callback');
add_action('wp_ajax_nopriv_dumbo_customizer_font_weight', 'dumbo_customizer_font_weight_callback');

// Recommendec Post Ajax Call Function.
function dumbo_customizer_font_weight_callback() {

    if ( isset( $_POST['_wpnonce'] ) && wp_verify_nonce( wp_unslash( $_POST['_wpnonce'] ), 'dumbo_ajax_nonce' ) && isset( $_POST['currentfont'] ) && sanitize_text_field( wp_unslash( $_POST['currentfont'] ) ) ) {

       $currentfont = sanitize_text_field( wp_unslash( $_POST['currentfont'] ) );
       $headings_fonts_property = Dumbo_Fonts::dumbo_get_fonts_property( $currentfont );

       foreach( $headings_fonts_property['weight'] as $key => $value ){
       		echo '<option value="'.esc_attr( $key ).'">'.esc_html( $value ).'</option>';
       }
    }
    wp_die();
}